@@ -22,9 +22,11 @@ __all__ = ["GeneralOptions", "SlurmOptions", "SnakemakeOptions",
     "CutadaptOptions", "KrakenOptions", "InputOptions", ]
 
 
-
-
 def init_pipeline(NAME):
+    print('deprecated, please use before_pipeline instead')
+    before_pipeline(NAME)
+
+def before_pipeline(NAME):
     """A function to provide --version and --deps for all pipelines
 
     """
